@@ -588,6 +588,8 @@ static PyMethodDef Billiard_connection_methods[] = {
       "send string/buffer (non-blocking)"},
     {"recv", (PyCFunction)Billiard_connection_recv_obj, METH_NOARGS,
      "receive a (picklable) object"},
+    {"setblocking",(PyCFunction)Billiard_connection_setblocking, METH_O,
+     "set socket blocking/non-blocking"},
     {"recv_payload", (PyCFunction)Billiard_connection_recv_payload, METH_NOARGS,
      "receive raw payload (not unpickled)"},
     {"poll", (PyCFunction)Billiard_connection_poll, METH_VARARGS,
