@@ -18,9 +18,8 @@
 #
 
 from __future__ import absolute_import
-from __future__ import with_statement
 
-VERSION = (2, 7, 3, 34)
+VERSION = (3, 3, 0, 0)
 __version__ = ".".join(map(str, VERSION[0:4])) + "".join(VERSION[4:])
 __author__ = 'R Oudkerk / Python Software Foundation'
 __author_email__ = 'python-dev@python.org'
@@ -94,10 +93,7 @@ def Pipe(duplex=True):
     '''
     Returns two connection object connected by a pipe
     '''
-    if sys.version_info[0] == 3:
-        from multiprocessing.connection import Pipe
-    else:
-        from billiard._connection import Pipe  # noqa
+    from billiard.connection import Pipe
     return Pipe(duplex)
 
 
@@ -241,7 +237,11 @@ def Pool(processes=None, initializer=None, initargs=(), maxtasksperchild=None,
     Returns a process pool object
     '''
     from .pool import Pool
-    return Pool(processes, initializer, initargs, maxtasksperchild)
+    return Pool(processes, initializer, initargs, maxtasksperchild,
+                timeout, soft_timeout, lost_worker_timeout,
+                max_restarts, max_restart_freq, on_process_up,
+                on_process_down, on_timeout_set, on_timeout_cancel,
+                threads, semaphore, putlocks, allow_restart)
 
 
 def RawValue(typecode_or_type, *args):
